# pytauri-wheel

## [Unreleased]

## [0.7.0]

### Fixed

- [#175](https://github.com/pytauri/pytauri/pull/175) - fix: bump `tauri-plugin-*` to fix rust docs build failures on `docs.rs`.

    See [tauri-apps/tauri#13597](https://github.com/tauri-apps/tauri/pull/13597#issuecomment-2961321899) for details.

    - `tauri-plugin-opener = { version = "2.3.0" }`
    - `tauri-plugin-clipboard-manager = { version = "2.2.3" }`
    - `tauri-plugin-dialog = { version = "2.2.2" }`
    - `tauri-plugin-fs = { version = "2.3.0" }`
    - `tauri-plugin-notification = { version = "2.2.3" }`

## [0.6.0]

### Added

- [#165](https://github.com/pytauri/pytauri/pull/165) - feat: enable `tauri-plugin-notification` and integrate `pytauri_plugins`.

## [0.5.0]

### Highlights

- [#139](https://github.com/pytauri/pytauri/pull/139) - feat: add support for the `windows-11-arm` platform wheel.

## [0.4.0]

the first release

[unreleased]: https://github.com/pytauri/pytauri/tree/HEAD
[0.7.0]: https://github.com/pytauri/pytauri/releases/tag/py/pytauri-wheel/v0.7.0
[0.6.0]: https://github.com/pytauri/pytauri/releases/tag/py/pytauri-wheel/v0.6.0
[0.5.0]: https://github.com/pytauri/pytauri/releases/tag/py/pytauri-wheel/v0.5.0
[0.4.0]: https://github.com/pytauri/pytauri/releases/tag/py/pytauri-wheel/v0.4.0
